@@ -23,18 +23,18 @@ Block tag function decorator
 
 Syntax::
 
-    @block([**options])
     def my_tag_function(context, nodelist, [*vars], [**tag_options]):
         return nodelist.render(context)
+    my_tag_function.block = True
 """)
 comparison = tag('comparison',"""
 Comparison tag function decorator
 
 Syntax::
 
-    @comparison([**options]):
     def my_comparison([*vars], [**tag_options]):
         return True
+    my_comparison.comparison = True
 """)
 comparison.__doc__
 filter = tag('filter',"""
@@ -42,16 +42,16 @@ Filter tag function decorator
 
 Syntax::
 
-    @filter([**options]):
     def my_filter(value, arg):
         return value
+    my_filter.filter = True
 """)
 function = tag('function',"""
 Function tag function decorator
 
 Syntax::
 
-    @function([**options]):
-    def my_function([*args], [**kwargs]):
+    def foo[*args], [**kwargs]):
         return args, kwargs
+    foo.function = True
 """)
